.. m_Librarian documentation master file, created by
   sphinx-quickstart on Wed Mar 30 22:46:31 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to m_Librarian's documentation!
=======================================

This hopefully will be a collection of programs to index LibRusEc and
Flibusta libraries (zipfiles from torrents, actually) and show their
contents with command-line, web interface and GUI.


Contents:

.. toctree::
   :maxdepth: 2

   before_begin
   install
   command_line
   news


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Credits
=======

Created by Oleg Broytman <phd@phdru.name>.

Copyright (C) 2015-2018 PhiloSoft Design.


License
=======

GPL.
